@@ -279,9 +279,6 @@ class RectFloorPhoto(BaseImage):
         :param empty_color: Empty base color. If -1, disable empty replace color
         """
         BaseImage.__init__(self, path, save_images, image_size_px)
-
-        if empty_color != -1:
-            print('Using debug mode with different empty color')
         assert -1 <= empty_color <= 255
 
         self._empty_color = empty_color  # Color to replace empty data
@@ -589,15 +586,11 @@ class RectFloorPhoto(BaseImage):
         """
         Close and delete all generated figures.
         """
-        del self._names
-        self._names = []
+        self._names.clear()
         self._processed_images = 0
-        del self._images
-        self._images = []
-        del self._floor_images
-        self._floor_images = {}
-        del self._floor_center_d
-        self._floor_center_d = {}
+        self._images.clear()
+        self._floor_images.clear()
+        self._floor_center_d.clear()
         gc.collect()
 
 
